--- layout: base title: What's New navbar_active: whats-new relative_path: ../ --- {% capture jumbotron_h1 %} What's New{% endcapture %} {% capture jumbotron_p %}What's New in the latest version — Font Awesome {{ site.fontawesome.minor_version }}{% endcapture %} {% include jumbotron.html %} {% include stripe-social.html %}
{% capture stripe_ad_content %}

Font Awesome is always getting a little awesome-er. So here's what's new in the latest version, Font Awesome {{ site.fontawesome.minor_version }}. Have some ideas for new features? Help contribute.

{% endcapture %} {% include stripe-ad.html %}

#### Accessibility Docs

Details on how to mark up your icons depending on how you're using them. Make your site icons usable by the most people, and start here.

#### Better Examples

Every FA icon example page now has a better, more accessibility-minded default block of code that users can copy and paste.

#### Accessibility Category

We've added a new icon category specifically for accessibility and seeded it with 15 icons to start. Make sure to request more if you need them!
{% include icons/new.html %} {% include new-upgrading.html %}